Benchmark

Struct Benchmark 

pub struct Benchmark<Env: Environment> { /* private fields */ }

Implementations

Source

impl<Env: Environment> Benchmark<Env>

pub async fn run_benchmark<C: ClientContext<Environment = Env> + 'static>( bps: usize, chain_clients: Vec<ChainClient<Env>>, generators: Vec<Box<dyn OperationGenerator>>, transactions_per_block: usize, health_check_endpoints: Option<String>, runtime_in_seconds: Option<u64>, delay_between_chains_ms: Option<u64>, chain_listener: ChainListener<C>, command_sender: UnboundedSender<ListenerCommand>, shutdown_notifier: &CancellationToken, ) -> Result<(), BenchmarkError>

Runs a benchmark with the given chain clients and operation generators.

Each chain client is paired with an operation generator (one per chain). The generators produce the operations to include in each block.

pub async fn close_benchmark_chain( chain_client: &ChainClient<Env>, ) -> Result<(), BenchmarkError>

Closes the chain that was created for the benchmark.

pub fn get_all_chains( chains_config_path: Option<&Path>, benchmark_chains: &[(ChainId, AccountOwner)], ) -> Result<Vec<ChainId>, BenchmarkError>