pub struct ExecuteOperationsTimingsHistograms {
pub execute_block_histogram: Histogram<u64>,
pub execute_block_timings_histograms: ExecuteBlockTimingsHistograms,
}Expand description
Histograms tracking the time spent executing operations, broken down by sub-phase.
Fields
execute_block_histogram: Histogram<u64>Time taken to execute a single block, in milliseconds.
execute_block_timings_histograms: ExecuteBlockTimingsHistogramsNested histograms for the block-execution sub-phases.
Implementations
Sourceimpl ExecuteOperationsTimingsHistograms
impl ExecuteOperationsTimingsHistograms
Sourcepub fn new() -> Result<Self, ClientMetricsError>
pub fn new() -> Result<Self, ClientMetricsError>
Creates a new set of operation-execution timing histograms.