pub struct Options {Show 43 fields
pub send_timeout: Duration,
pub recv_timeout: Duration,
pub max_pending_message_bundles: usize,
pub max_block_limit_errors: u32,
pub max_new_events_per_block: usize,
pub staging_bundles_time_budget: Option<Duration>,
pub prioritize_bundles_from: Option<HashSet<ChainId>>,
pub ignore_bundles_from: Option<HashSet<ChainId>>,
pub chain_worker_ttl: Duration,
pub sender_chain_worker_ttl: Duration,
pub cross_chain_batch_size_limit: usize,
pub retry_delay: Duration,
pub max_retries: u32,
pub max_backoff: Duration,
pub notification_circuit_breaker_initial_probe_interval: Duration,
pub notification_circuit_breaker_max_probe_interval: Duration,
pub wait_for_outgoing_messages: bool,
pub allow_fast_blocks: bool,
pub long_lived_services: bool,
pub blanket_message_policy: BlanketMessagePolicy,
pub restrict_chain_ids_to: Option<HashSet<ChainId>>,
pub reject_message_bundles_without_application_ids: Option<HashSet<GenericApplicationId>>,
pub reject_message_bundles_with_other_application_ids: Option<HashSet<GenericApplicationId>>,
pub process_events_from_application_ids: Option<HashSet<GenericApplicationId>>,
pub never_reject_application_ids: Option<HashSet<GenericApplicationId>>,
pub timings: bool,
pub timing_interval: u64,
pub quorum_grace_period: f64,
pub blob_download_hedge_delay: Duration,
pub certificate_batch_download_hedge_delay: Duration,
pub certificate_download_batch_size: u64,
pub certificate_upload_batch_size: u64,
pub sender_certificate_download_batch_size: usize,
pub max_concurrent_batch_downloads: usize,
pub max_joined_tasks: usize,
pub max_event_stream_queries: usize,
pub max_accepted_latency_ms: f64,
pub cache_ttl_ms: u64,
pub cache_max_size: usize,
pub max_request_ttl_ms: u64,
pub alpha: f64,
pub alternative_peers_retry_delay_ms: u64,
pub chain_listener_config: ChainListenerConfig,
}Expand description
Command-line options controlling the behavior of the chain client.
Fields
send_timeout: DurationTimeout for sending queries (milliseconds)
recv_timeout: DurationTimeout for receiving responses (milliseconds)
max_pending_message_bundles: usizeThe maximum number of incoming message bundles to include in a block proposal.
max_block_limit_errors: u32Maximum number of message bundles to discard from a block proposal due to block limit errors before discarding all remaining bundles.
Discarded bundles can be retried in the next block.
max_new_events_per_block: usizeThe maximum number of new stream events to include in a block proposal.
staging_bundles_time_budget: Option<Duration>Time budget for staging message bundles in milliseconds. When set, limits bundle
execution by wall-clock time, in addition to the count limit from
max_pending_message_bundles.
prioritize_bundles_from: Option<HashSet<ChainId>>Comma-separated list of chain IDs whose incoming bundles should be processed first.
ignore_bundles_from: Option<HashSet<ChainId>>Comma-separated list of chain IDs whose incoming bundles should be ignored.
chain_worker_ttl: DurationThe duration in milliseconds after which an idle chain worker will free its memory.
sender_chain_worker_ttl: DurationThe duration, in milliseconds, after which an idle sender chain worker will free its memory.
cross_chain_batch_size_limit: usizeMaximum number of cross-chain requests coalesced into a single batch by the per-chain driver. Bounds the worst-case write-lock hold time.
retry_delay: DurationDelay increment for retrying to connect to a validator.
max_retries: u32Number of times to retry connecting to a validator.
max_backoff: DurationMaximum backoff delay for retrying to connect to a validator.
notification_circuit_breaker_initial_probe_interval: DurationInitial probe interval (ms) for the notification circuit breaker. When a validator’s notification stream exhausts retries, the circuit breaker waits this long before probing again. Doubles on each failed probe.
notification_circuit_breaker_max_probe_interval: DurationMaximum probe interval (ms) for the notification circuit breaker. The probe interval doubles on each failure but is capped at this value.
wait_for_outgoing_messages: boolWhether to wait until a quorum of validators has confirmed that all sent cross-chain messages have been delivered.
allow_fast_blocks: boolWhether to allow creating blocks in the fast round. Fast blocks have lower latency but must be used carefully so that there are never any conflicting fast block proposals.
long_lived_services: bool(EXPERIMENTAL) Whether application services can persist in some cases between queries.
blanket_message_policy: BlanketMessagePolicyThe policy for handling incoming messages.
restrict_chain_ids_to: Option<HashSet<ChainId>>A set of chains to restrict incoming messages and events from. By default, messages and events from all chains are accepted. To reject all of them, specify an empty string. The admin chain’s event stream is always followed regardless of this setting.
reject_message_bundles_without_application_ids: Option<HashSet<GenericApplicationId>>A set of application IDs. If specified, only bundles with at least one message from one of these applications will be accepted.
reject_message_bundles_with_other_application_ids: Option<HashSet<GenericApplicationId>>A set of application IDs. If specified, only bundles where all messages are from one of these applications will be accepted.
process_events_from_application_ids: Option<HashSet<GenericApplicationId>>A set of application IDs. If specified, only event streams created by applications from this set are processed and followed. The admin chain’s event stream is always followed.
never_reject_application_ids: Option<HashSet<GenericApplicationId>>A set of application IDs whose messages must never be rejected. Bundles whose messages
are all from one of these applications bypass the other rejection rules (except
--restrict-chain-ids-to), and on execution failure they (and subsequent bundles from
the same sender) are removed from the block for later retry instead of being rejected,
with a warning logged. Bundles that contain any message from an application not on this
list can be rejected.
timings: boolEnable timing reports during operations
timing_interval: u64Interval in seconds between timing reports (defaults to 5)
quorum_grace_period: f64An additional delay, after reaching a quorum, to wait for additional validator signatures, as a fraction of time taken to reach quorum.
blob_download_hedge_delay: DurationThe delay when downloading a blob, after which we try a second validator, in milliseconds.
certificate_batch_download_hedge_delay: DurationThe delay when downloading a batch of certificates, after which we try a second validator, in milliseconds.
certificate_download_batch_size: u64Maximum number of certificates that we download at a time from one validator when synchronizing one of our chains.
certificate_upload_batch_size: u64Maximum number of certificates read from local storage and uploaded to a validator at a time when synchronizing a chain.
sender_certificate_download_batch_size: usizeMaximum number of sender certificates we try to download and receive in one go when syncing sender chains.
max_concurrent_batch_downloads: usizeMaximum number of certificate batches downloaded concurrently during chain sync.
max_joined_tasks: usizeMaximum number of tasks that can are joined concurrently in the client.
max_event_stream_queries: usizeMaximum number of event stream IDs to include in a single PreviousEventBlocks
request. Larger sets are split into multiple requests.
max_accepted_latency_ms: f64Maximum expected latency in milliseconds for score normalization.
cache_ttl_ms: u64Time-to-live for cached responses in milliseconds.
cache_max_size: usizeMaximum number of entries in the cache.
max_request_ttl_ms: u64Maximum latency for an in-flight request before we stop deduplicating it (in milliseconds).
alpha: f64Smoothing factor for Exponential Moving Averages (0 < alpha < 1). Higher values give more weight to recent observations. Typical values are between 0.01 and 0.5. A value of 0.1 means that 10% of the new observation is considered and 90% of the previous average is retained.
alternative_peers_retry_delay_ms: u64Delay in milliseconds between starting requests to different peers. This helps to stagger requests and avoid overwhelming the network.
chain_listener_config: ChainListenerConfigConfiguration for the chain listener.