pub struct ApplicationPermissionsConfig {
pub execute_operations: Option<Option<Vec<ApplicationId>>>,
pub mandatory_applications: Option<Vec<ApplicationId>>,
pub close_chain: Option<Vec<ApplicationId>>,
pub change_application_permissions: Option<Vec<ApplicationId>>,
pub call_service_as_oracle: Option<Option<Vec<ApplicationId>>>,
pub make_http_requests: Option<Option<Vec<ApplicationId>>>,
}Fields
execute_operations: Option<Option<Vec<ApplicationId>>>A JSON list of applications allowed to execute operations on this chain. If set to null, all operations will be allowed. Otherwise, only operations from the specified applications are allowed, and no system operations. Absence of the option leaves current permissions unchanged.
mandatory_applications: Option<Vec<ApplicationId>>A JSON list of applications, such that at least one operation or incoming message from each of these applications must occur in every block. Absence of the option leaves current mandatory applications unchanged.
close_chain: Option<Vec<ApplicationId>>A JSON list of applications allowed to close the chain. Absence of the option leaves the current list unchanged.
change_application_permissions: Option<Vec<ApplicationId>>A JSON list of applications allowed to change the application permissions on the current chain using the system API. Absence of the option leaves the current list unchanged.
call_service_as_oracle: Option<Option<Vec<ApplicationId>>>A JSON list of applications that are allowed to call services as oracles on the current chain using the system API. If set to null, all applications will be able to do so. Absence of the option leaves the current value of the setting unchanged.
make_http_requests: Option<Option<Vec<ApplicationId>>>A JSON list of applications that are allowed to make HTTP requests on the current chain using the system API. If set to null, all applications will be able to do so. Absence of the option leaves the current value of the setting unchanged.
Implementations
Sourceimpl ApplicationPermissionsConfig
impl ApplicationPermissionsConfig
pub fn update(self, application_permissions: &mut ApplicationPermissions)