Options

Struct Options 

pub struct Options {
Show 32 fields pub send_timeout: Duration, pub recv_timeout: Duration, pub max_pending_message_bundles: usize, pub max_block_limit_errors: u32, pub max_new_events_per_block: usize, pub chain_worker_ttl: Duration, pub sender_chain_worker_ttl: Duration, pub retry_delay: Duration, pub max_retries: u32, pub max_backoff: Duration, pub wait_for_outgoing_messages: bool, pub allow_fast_blocks: bool, pub long_lived_services: bool, pub blanket_message_policy: BlanketMessagePolicy, pub restrict_chain_ids_to: Option<HashSet<ChainId>>, pub reject_message_bundles_without_application_ids: Option<HashSet<GenericApplicationId>>, pub reject_message_bundles_with_other_application_ids: Option<HashSet<GenericApplicationId>>, pub timings: bool, pub timing_interval: u64, pub quorum_grace_period: f64, pub blob_download_timeout: Duration, pub certificate_batch_download_timeout: Duration, pub certificate_download_batch_size: u64, pub sender_certificate_download_batch_size: usize, pub max_joined_tasks: usize, pub max_accepted_latency_ms: f64, pub cache_ttl_ms: u64, pub cache_max_size: usize, pub max_request_ttl_ms: u64, pub alpha: f64, pub alternative_peers_retry_delay_ms: u64, pub chain_listener_config: ChainListenerConfig,
}

Fields

send_timeout: Duration

Timeout for sending queries (milliseconds)

recv_timeout: Duration

Timeout for receiving responses (milliseconds)

max_pending_message_bundles: usize

The maximum number of incoming message bundles to include in a block proposal.

max_block_limit_errors: u32

Maximum number of message bundles to discard from a block proposal due to block limit errors before discarding all remaining bundles.

Discarded bundles can be retried in the next block.

max_new_events_per_block: usize

The maximum number of new stream events to include in a block proposal.

chain_worker_ttl: Duration

The duration in milliseconds after which an idle chain worker will free its memory.

sender_chain_worker_ttl: Duration

The duration, in milliseconds, after which an idle sender chain worker will free its memory.

retry_delay: Duration

Delay increment for retrying to connect to a validator.

max_retries: u32

Number of times to retry connecting to a validator.

max_backoff: Duration

Maximum backoff delay for retrying to connect to a validator.

wait_for_outgoing_messages: bool

Whether to wait until a quorum of validators has confirmed that all sent cross-chain messages have been delivered.

allow_fast_blocks: bool

Whether to allow creating blocks in the fast round. Fast blocks have lower latency but must be used carefully so that there are never any conflicting fast block proposals.

long_lived_services: bool

(EXPERIMENTAL) Whether application services can persist in some cases between queries.

blanket_message_policy: BlanketMessagePolicy

The policy for handling incoming messages.

restrict_chain_ids_to: Option<HashSet<ChainId>>

A set of chains to restrict incoming messages from. By default, messages from all chains are accepted. To reject messages from all chains, specify an empty string.

reject_message_bundles_without_application_ids: Option<HashSet<GenericApplicationId>>

A set of application IDs. If specified, only bundles with at least one message from one of these applications will be accepted.

reject_message_bundles_with_other_application_ids: Option<HashSet<GenericApplicationId>>

A set of application IDs. If specified, only bundles where all messages are from one of these applications will be accepted.

timings: bool

Enable timing reports during operations

timing_interval: u64

Interval in seconds between timing reports (defaults to 5)

quorum_grace_period: f64

An additional delay, after reaching a quorum, to wait for additional validator signatures, as a fraction of time taken to reach quorum.

blob_download_timeout: Duration

The delay when downloading a blob, after which we try a second validator, in milliseconds.

certificate_batch_download_timeout: Duration

The delay when downloading a batch of certificates, after which we try a second validator, in milliseconds.

certificate_download_batch_size: u64

Maximum number of certificates that we download at a time from one validator when synchronizing one of our chains.

sender_certificate_download_batch_size: usize

Maximum number of sender certificates we try to download and receive in one go when syncing sender chains.

max_joined_tasks: usize

Maximum number of tasks that can are joined concurrently in the client.

max_accepted_latency_ms: f64

Maximum expected latency in milliseconds for score normalization.

cache_ttl_ms: u64

Time-to-live for cached responses in milliseconds.

cache_max_size: usize

Maximum number of entries in the cache.

max_request_ttl_ms: u64

Maximum latency for an in-flight request before we stop deduplicating it (in milliseconds).

alpha: f64

Smoothing factor for Exponential Moving Averages (0 < alpha < 1). Higher values give more weight to recent observations. Typical values are between 0.01 and 0.5. A value of 0.1 means that 10% of the new observation is considered and 90% of the previous average is retained.

alternative_peers_retry_delay_ms: u64

Delay in milliseconds between starting requests to different peers. This helps to stagger requests and avoid overwhelming the network.

chain_listener_config: ChainListenerConfig